classdef BenchmarkApp < handle
    %BenchmarkApp Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        gui = [];
        parameterSet = [];
        
        TargetChangeParam = [];
        GeneralizationParam = [];
        PushesParam = [];
        ContPushesParam = [];
        
        statemachine = [];
        adaptiveModuleAssistant = [];
        primitive= [];
        currState =0;
        numRandSamples=1;
    end
    
    methods
        function app = BenchmarkApp()
            app.parameterSet = CustomParameters();
            app.gui = BenchmarkGUI(app);
            %app.parameterAssistant = parameterAssistant(app,app.gui.statePanel);
            app.statemachine = StateMachineUI(app, app.gui.BenchmarkPanel);
            app.GeneralizationParam = GeneralizationParam(app,app.gui.statePanel);
            app.PushesParam = PushesParam(app,app.gui.statePanel);
            app.ContPushesParam = ContPushesParam(app,app.gui.statePanel);
            app.TargetChangeParam = TargetChangeParam(app,app.gui.statePanel);
            set(app.statemachine.uis.selectMenu, 'Value',1);
            
            app.statemachine.setState(1);
        end
        
        function init(app)
            app.parameterSet.pushes.parentup = app.gui.varPanel;
            app.parameterSet.cont_pushes.parentup = app.gui.varPanel;
            app.parameterSet.generalization.parentup = app.gui.varPanel;
            app.parameterSet.target.parentup = app.gui.varPanel;
            
        end
        
        function startBenchmark(app,src,evn)
            app.init
            app.statemachine.getParameters();
            app.TargetChangeParam.getParameters();
            app.GeneralizationParam.getParameters();
            app.PushesParam.getParameters();
            app.ContPushesParam.getParameters();
            
            parameters = app.parameterSet;
            
            %% load the model
            disp('Loading the model ...');
            for ikl =  1:length(parameters.model)
                modelName = parameters.model{ikl};
                load([parameters.folder_dataset filesep 'DataSet' filesep modelName]); % loading demos
                
                opt_sim.dt = dt; %using the same time steps as demosntration (make it easier for evaluation)
                opt_sim.i_max = 3*size(demos{1}.pos,2);
                opt_sim.tol = 1;
                
                resultDir = ['results' filesep parameters.folder_dataset filesep  parameters.folder_models  filesep  modelName(1:end-4)];
                
                
                if isempty(regexp(path,[parameters.folder_library pathsep], 'once'))
                    addpath([pwd, filesep parameters.folder_library]);    % add the library dir to path
                end
                
                load([parameters.folder_dataset filesep parameters.folder_models filesep modelName]); % loading the model
                if ~isa(model,'MovementGenerator')
                    error('please use recommended Class implementation')
                end
                disp(['Model ' modelName ' is loaded successfully.']);
                
                set(app.statemachine.uis.start_btn,'Enable','off');
                set(app.statemachine.uis.stop_btn,'Enable','on');
                app.primitive = model;
                listing = dir([parameters.folder_dataset filesep parameters.folder_models filesep modelName]);
                app.primitive.bytes = listing.bytes;
                
                demoEvaluation=evaluateDemos(demos,0); % do not draw
                %% running benchmarks
                if ~exist(resultDir,'dir')
                    mkdir(resultDir)
                end
                
                if ~(parameters.pushes.run || parameters.cont_pushes.run || parameters.target.run || parameters.generalization.run || parameters.obstacle.run)
                    errordlg('In order to run the software, you need to activate ''Run Benchmark'' on the top-right panel for at least one of the benchmarks.','Error','modal');
                end
                
                if (parameters.generalization.run)
                    parameters.generalization.model = modelName;
                    parameters.generalization.resultFileWithPath = strcat(resultDir, filesep, parameters.generalization.resultFile);
                    parameters.generalization.demoEvaulation=demoEvaluation;
                    PushesBenchmark(parameters.generalization, app.primitive, demos, opt_sim, false);
                end
                if app.primitive.checkAbourt
                    break;
                end
                
                if (parameters.pushes.run)
                    parameters.pushes.model = modelName;
                    parameters.pushes.resultFileWithPath = strcat(resultDir, filesep, parameters.pushes.resultFile);
                    parameters.pushes.demoEvaulation=demoEvaluation;
                    PushesBenchmark(parameters.pushes, app.primitive, demos, opt_sim, true);
                end
                if app.primitive.checkAbourt
                    break;
                end
                
                if (parameters.cont_pushes.run)
                    parameters.cont_pushes.model = modelName;
                    parameters.cont_pushes.resultFileWithPath = strcat(resultDir, filesep, parameters.cont_pushes.resultFile);
                    parameters.cont_pushes.demoEvaulation=demoEvaluation;
                    ContPushesBenchmark(parameters.cont_pushes, app.primitive, demos, opt_sim);
                end
                if app.primitive.checkAbourt
                    break;
                end
                
                if (parameters.target.run)
                    parameters.target.model = modelName;
                    parameters.target.resultFileWithPath = strcat(resultDir, filesep, parameters.target.resultFile);
                    parameters.target.demoEvaulation=demoEvaluation;
                    MovingTargetBenchmark(parameters.target, app.primitive, demos, opt_sim);
                end
                if app.primitive.checkAbourt
                    break;
                end
                
                if (parameters.obstacle.run)
                    parameters.obstacle.model = modelName;
                    parameters.obstacle.resultFileWithPath = strcat(resultDir, filesep, parameters.obstacle.resultFile);
                    parameters.obstacle.demoEvaulation=demoEvaluation;
                    ObstacleBenchmark(parameters.obstacle, app.primitive, demos, opt_sim);
                end
                if app.primitive.checkAbourt
                    break;
                end
            end
            set(app.statemachine.uis.start_btn,'Enable','on');
            set(app.statemachine.uis.stop_btn,'Enable','off');
        end
        
        function stopBenchmak(app,src,evn)
            if ~isempty(app.primitive)
                app.primitive.doAbourt();
            end
        end
        
        function delete(app)
            delete(app.gui);
            %if ~isempty(app.icub)
            %    delete(app.icub);
            %end
        end
        
      
        function getRandParameters(ga,src,evn)
            %TODO save current selected parameters
            [benchmarkType, numState] = ga.statemachine.getState();
            ga.statemachine.setState(numState);
            parameters = ga.parameterSet;
            
            if strcmpi(benchmarkType,'generalization')
                nbSamples= str2num(get(ga.GeneralizationParam.uis.setNumSample,'string'));
                samples = generateRandomBaselineParameters(nbSamples, benchmarkType);
                parameters.generalization.amplitude = samples.amplitude;
                parameters.generalization.vector = samples.vector;
                
            elseif strcmpi(benchmarkType,'discretePush')
                
                nbSamples= str2num(get(ga.PushesParam.uis.setNumSample,'string'));
                samples = generateRandomBaselineParameters(nbSamples, benchmarkType);
                parameters.pushes.amplitude = samples.amplitude;
                parameters.pushes.vector = samples.vector;
                parameters.pushes.start_time = samples.time;
            elseif strcmpi(benchmarkType,'continuousPush')
                nbSamples= str2num(get(ga.ContPushesParam.uis.setNumSample,'string'));
                samples = generateRandomBaselineParameters(nbSamples, benchmarkType);
                parameters.cont_pushes.amplitude= samples.amplitude;
                parameters.cont_pushes.vector= samples.vector;
                parameters.cont_pushes.start_time= samples.time;
                parameters.cont_pushes.duration= samples.duration;
            elseif strcmpi(benchmarkType,'targetChange')
                nbSamples= str2num(get(ga.TargetChangeParam.uis.setNumSample,'string'));
                samples = generateRandomBaselineParameters(nbSamples, benchmarkType);
                parameters.target.amplitude= samples.amplitude;
                parameters.target.vector= samples.vector;
                parameters.target.start_time= samples.time;
                parameters.target.duration= samples.duration;
            end
            ga.parameterSet =parameters;
            ga.TargetChangeParam.updateUI();
            ga.GeneralizationParam.updateUI();
            ga.PushesParam.updateUI();
            ga.ContPushesParam.updateUI();
            ga.statemachine.setState(numState);
            
        end
        
        function loadParam(ga,src,evn)
            [filename path] = uigetfile('*.mat', 'Load parameters from...', ['..' filesep 'data' filesep 'param' filesep 'param01']);
            
            if filename ~= 0
                load([path filesep filename], 'parameters');
                %TODO go to inspection view (construct state as if just trained)
                ga.parameterSet = parameters ;
                ga.statemachine.setParameters(parameters);
            end
            ga.TargetChangeParam.updateUI();
            ga.GeneralizationParam.updateUI();
            ga.PushesParam.updateUI();
            ga.ContPushesParam.updateUI();
            
        end
        
        function saveParam(ga,src,evn)
            [filename path] = uiputfile('*.mat', 'Save parameters as...', ['..' filesep 'data' filesep 'param' ]);
            
            if filename ~= 0
                ga.statemachine.getParameters();
                ga.TargetChangeParam.getParameters();
                ga.GeneralizationParam.getParameters();
                ga.PushesParam.getParameters();
                ga.ContPushesParam.getParameters();
                parameters = ga.parameterSet;
                save([path filesep filename], 'parameters');
                
                
                disp(['saved parameters to ' path filesep filename]);
            end
        end
        
        function getAboutInformations(ga,src,evn)
            DLGNAME = 'Benchmark Developers';
            HELPSTRING = [...
                'Main developers:                                    ';...
                'Andre Lemme, CoR-Lab, University Bielfeld           ';...
                'D-33615 Bielefeld, Germany, http://cor-lab.de       ';...
                '                                                    ';	 ...
                'Mohammad Khansari-Zadeh, LASA Lab, EPFL             ';...
                'CH-1015 Lausanne, Switzerland, http://lasa.epfl.ch  ';...
                '                                                    ';...
                'Contributers:                                       ';...
                'Yaron Meirovitch, Weizmann Institute of Science     ';...
                '7632700 Rehovot, Israel, http://www.weizmann.ac.il  ';...
                '                                                    ';...
                'Sebastien Gay, Biorobotics Laboratory, EPFL         ';...
                'CH-1015 Lausanne, Switzerland, http://lasa.epfl.ch  ';...
                ];
            helpdlg(HELPSTRING,DLGNAME)
%             disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
%             disp('% Main developer:                                     %')
%             disp('% Andre Lemme, CoR-Lab, University Bielfeld           %')
%             disp('% D-33615 Bielefeld, Germany, http://cor-lab.de       %')
%             disp('%                                                     %')	 
%             disp('% Mohammad Khansari-Zadeh, LASA Lab, EPFL             %')
%             disp('% CH-1015 Lausanne, Switzerland, http://lasa.epfl.ch  %')
%             disp('%                                                     %')	 
%             disp('% Contributor:                                         %')	 
%             disp('% Yaron Meirovitch, Weizmann Institute of Science     %')
%             disp('% 7632700 Rehovot, Israel, http://www.weizmann.ac.il  %')
%             disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
        end
    end
    
end

