
function [end_effector] = ForwardKinematics(jointAngles)
%Computes the end effector position given some specified joint angles for
%the shoulder and the elbow (4D)
%jointAngles : a 4D vector defining the joint angles of the shoulder
%           (pitch, roll, yaw) and the elbow.
%end_effector: a 3D vector containing the end effector position.
jointAngles = [0 0 0 jointAngles(1) jointAngles(2) jointAngles(3) jointAngles(4) 0 0 0];
DH = DHParams();

DHMat4 = EvalDHMatrix(jointAngles(4), DH{4});
DHMat5 = EvalDHMatrix(jointAngles(5), DH{5});
DHMat6 = EvalDHMatrix(jointAngles(6), DH{6});
DHMat7 = EvalDHMatrix(jointAngles(7), DH{7});
DHMat8 = EvalDHMatrix(jointAngles(8), DH{8});
DHMat9 = EvalDHMatrix(jointAngles(9), DH{9});
DHMat10 = EvalDHMatrix(jointAngles(10), DH{10});

T0 = ArmTRo0();

%Reference frames attached to links
transformation_matrix = T0  * DHMat4 * DHMat5 * DHMat6 * DHMat7 * DHMat8 * DHMat9 * DHMat10;
end_effector  = transformation_matrix * [0 0 0 1]';
end_effector = end_effector(1:3);

end