%=========================================================================%
function PlotResults(repros, demos, xt, scores, varargin)
if isempty(varargin)
    options = check_options();
else
    options = check_options(varargin{1}); % checking the given options, and add ones are not defined.
end
obstacle = options.obstacle;
hasobstacle = options.hasobstacle;


% data = [];
% for i=1:length(demos)
%     data = [data demos{i}];
% end

if isempty(options.parentup) % plotting the result
    screensize = get(0,'screensize');
    options.parentup = figure('name','results from simulation','position',[0   0   screensize(3)   screensize(4)/2]);
end

 %----
axlist = get(options.parentup,'children');
ystr = {' ','  Processing\newline Time (msec)', 'Module Size\newline    (bytes)';
        'Target Position\newline    Error (mm)','Target Velocity\newline  Error (mm/s)', 'Mean Jerk (m/s^3)';
        'Path Error (mm)','Trajectory Velocity\newline      Error (mm/s)','  Power Law\newline Score (%R^2)';
        'R2','R2 speed','    Movement\newline Duration Error'};

if isempty(axlist)
    %%
    sp(1)=subplot(2,2,1, 'Parent', options.parentup, 'Position',[0.06    0.73    0.3347    0.25]);
    xlabel(sp(1),'$x (mm)$','interpreter','latex','fontsize',13);
    ylabel(sp(1),'$y (mm)$','interpreter','latex','fontsize',13);
    hold(sp(1), 'on'); box(sp(1), 'on');grid(sp(1), 'on');
    axis(sp(1),'equal')

    sp(2)=subplot(2,2,2,'Parent', options.parentup,'Position',[0.48    0.73    0.3347    0.25]);
    xlabel(sp(2),'$time step$','interpreter','latex','fontsize',13);
    ylabel(sp(2),'$\dot{v} (mm/s)$','interpreter','latex','fontsize',13);
    hold(sp(2), 'on'); box(sp(2), 'on');grid(sp(2), 'on');
    
    ss = zeros(size(ystr));
    for i=1:size(ss,1)
        for j=1:size(ss,2)
            ss(i,j) = subplot(2+size(ss,1),size(ss,2),(i+1)*size(ss,2)+j, 'Parent', options.parentup);
            if i==size(ss,1)
                xlabel(ss(i,j),'iteration','fontsize',8.5);
            end
            ylabel(ss(i,j),ystr{i,j},'fontsize',8.5);
            hold(ss(i,j), 'on'); box(ss(i,j), 'on');grid(ss(i,j), 'on');
        end
    end
    pos0 = [0.07    0.52    0.245    0.120];
    for i=1:size(ss,1)
        for j=1:size(ss,2)
            set(ss(i,j),'Position',pos0 + [(j-1)*0.34 -(i-1)*0.154 0 0])
            if i==1 && j==1 %making a dummy subplot
                set(ss(i,j),'Position',[-0.125 pos0(2) 0.001 0.001],'XTick',[],'YTick',[])
            end
        end
    end
    
    annotation(get(options.parentup,'parent'), 'textbox',[0.064 0.37 0.25 0.06],'string','   Results for the \newlinerunning benchmark',...
        'Fontsize',15,'HorizontalAlignment','center','LineStyle','none');
else
    sp = axlist(end:-1:end-1);
    ss = reshape(axlist(end-2:-1:2),3,[])';
    hold(sp(1),'off')
    hold(sp(2),'off')
end

for i=1:length(demos)
    demo_ax= plot(sp(1),demos{i}.pos(1,:),demos{i}.pos(2,:),'r--','linewidth',2);
    if ~ishold(sp(1))
        hold(sp(1),'on');
        xlabel(sp(1),'$x (mm)$','interpreter','latex','fontsize',15);
        ylabel(sp(1),'$y (mm)$','interpreter','latex','fontsize',15);
        axis(sp(1),'equal')
    end
end

if(hasobstacle)
    for i=1:length(obstacle.position)
        DrawObstacle(obstacle.position(:, i), obstacle.radius,sp(1));
    end
end

for i=1:length(repros)
    repro_ax= plot(sp(1),repros{i}(1,:),repros{i}(2,:),'linewidth',2);
    plot(sp(1),repros{i}(1,1),repros{i}(2,1),'ok','markersize',5,'linewidth',5);
    dom=scores(end).demos(i).domain;
    plot(sp(2),find(dom),sqrt(sum(repros{i}(3:4,dom).^2)),'b.','linewidth',2); 
    plot(sp(2),find(~dom),0*find(~dom),'.k'); 
    if ~ishold(sp(2))
        hold(sp(2),'on');
        xlabel(sp(2),'$time step$','interpreter','latex','fontsize',15);
        ylabel(sp(2),'$\dot{v} (mm/s)$','interpreter','latex','fontsize',15);
    end
    plot(sp(2),sqrt(sum(demos{i}.vel.^2)),'r.','linewidth',2);
end

% for i=1:2
%     %axis(sp(i),'equal');
%     ax=get(sp(i));
%     axis(sp(i),...
%         [ax.XLim(1)-(ax.XLim(2)-ax.XLim(1))/10 ax.XLim(2)+(ax.XLim(2)-ax.XLim(1))/10 ...
%         ax.YLim(1)-(ax.YLim(2)-ax.YLim(1))/10 ax.YLim(2)+(ax.YLim(2)-ax.YLim(1))/10]);
% end
tar_ax =plot(sp(1),xt(1,end),xt(2,end),'k*','markersize',15,'linewidth',3);

if ~isempty(options.matched_repros)
    matched_repros=options.matched_repros;
    for i=1:length(demos)
        match_ax= plot(sp(1),matched_repros{i}(1,:),matched_repros{i}(2,:),'g--','linewidth',2);
        plot(sp(1),matched_repros{i}(1,1),matched_repros{i}(2,1),'ok','markersize',5,'linewidth',5);
        %plot(sp(2),sqrt(sum(matched_repros{i}(3:4,:).^2)),'g--'); hold on
    end
    
end

l=legend([tar_ax, demo_ax,repro_ax ,match_ax],'target','demonstrations','reproductions','matched reproductions' );
posl = get(l,'position');
set(l,'position',[0.795    0.84    posl(3:4)])

%%
%axis(sp(1),'equal')
axis(sp(1),'equal')
ax=get(sp(1));
daspect(sp(1),[1 1 1]);
axis(sp(1),...
    [ax.XLim(1)-(ax.XLim(2)-ax.XLim(1))/10 ax.XLim(2)+(ax.XLim(2)-ax.XLim(1))/10 ...
    ax.YLim(1)-(ax.YLim(2)-ax.YLim(1))/10 ax.YLim(2)+(ax.YLim(2)-ax.YLim(1))/10]);
grid(sp(1),'on'); box(sp(1),'on');
axis(sp(1),'tight')
ax=get(sp(2));
axis(sp(2),[ax.XLim ...
    ax.YLim(1)-(ax.YLim(2)-ax.YLim(1))/10 ax.YLim(2)+(ax.YLim(2)-ax.YLim(1))/10]);
grid(sp(2),'on'); box(sp(2),'on');
%%
% set(sp(1),'position',[0.08    0.5838    0.3347    0.35])
% set(sp(2),'position',[0.08    0.1    0.3347    0.35])
%%
nIter = length(scores);
for i=1:length(scores(nIter).demos)
    
    domain{i} =  scores(nIter).demos(i).domain;
    targetErrorPos(i) = norm(scores(nIter).demos(i).target_error.position);
    targetErrorVel(i) = norm(scores(nIter).demos(i).target_error.velocity);
    trajErrorPos(i) = norm(scores(nIter).demos(i).trajectory_error.position);
    trajErrorVel(i) = norm(scores(nIter).demos(i).trajectory_error.velocity);
    maxJerk(i) = norm(scores(nIter).demos(i).max_jerk);
    meanJerk(i) = norm(scores(nIter).demos(i).mean_jerk);
    vssq(i) = scores(nIter).demos(i).vssq;
    R2(i) = scores(nIter).demos(i).R2;
    R2_speed(i) = scores(nIter).demos(i).R2_speed;
    PL_R2(i) = scores(nIter).demos(i).PL_R2;
    computationTime(i) = mean(scores(nIter).demos(i).computationTime)*1000; %converting to msec
    normalizedFinalTime(i) = mean(abs(1-scores(nIter).demos(i).normalizedFinalTime));
    
end
modelSize = scores(nIter).modelSize;

%%
vStr = {' ','computationTime','modelSize';
        'targetErrorPos','targetErrorVel','meanJerk';
        'trajErrorPos','trajErrorVel','PL_R2';
        'R2','R2_speed','normalizedFinalTime'};
    
for i=1:size(ss,1)
    for j=1:size(ss,2)
        if ~(i==1 && j==1)
            if nIter == 1
                hold(ss(i,j),'off');
            end
            eval(['curVariable = ' vStr{i,j} ';'])
            plot(ss(i,j),nIter,mean(curVariable),'bo')
            if ~ishold(ss(i,j))
                hold(ss(i,j),'on');
                xlabel(ss(i,j),'iteration','fontsize',9);
                ylabel(ss(i,j),ystr{i,j},'fontsize',9);
            end
            errorbar(ss(i,j),nIter,mean(curVariable),sqrt(var(curVariable)),'k')

            axis(ss(i,j),'tight')
            ax=get(ss(i,j));
            axis(ss(i,j),...
                [0.5 nIter+0.5 ...
                ax.YLim(1)-(ax.YLim(2)-ax.YLim(1))/10 ax.YLim(2)+(ax.YLim(2)-ax.YLim(1))/10]);
            set(ss(i,j),'XTick',1:ceil(nIter/10):nIter);
        end
    end
end
    
%%
if options.animation
    %screensize = get(0,'screensize');
    %figure('name','animation','position',[0   screensize(4)/2   screensize(3)   screensize(4)/2]);
    figAnim = figure('name','animation');
    delta = [-200 100 0];
    
    obstacle.exists = hasobstacle;
    target.radius = 10;
    lastq = [0 0 0 0];
    skipframes = 3;
    
    thisobs.exists = obstacle.exists;
    if(hasobstacle)
        obstacle.position = [obstacle.position ; zeros(1, length(obstacle.position))] + repmat(delta', 1, length(obstacle.position));
        thisobs.position = obstacle.position(:, 2);
        thisobs.radius = obstacle.radius;
    end
    x= repros{2};
    for i=1:skipframes:size(x, 2)%loop over time
        target.position = [xt(1,i) xt(2,i) 0] + delta;
        hold on;
        thispos = [x(1,i) x(2,i) 0] + delta;
        
        %cd fwd-inv-kinematics
        [q, err] = InverseKinematics(thispos, lastq);
        %cd ..;
        figure(figAnim)
        %cd visualization;
        AnimateiCub(q, target, thisobs);
        %cd ..;
        
        lastq = q;
        zer = zeros(1, i);
        delt = repmat(delta', 1, i);
        dat = [x(1,1:i) ; x(2,1:i) ; zer ] + delt;
        
        plot3(dat(1, :), dat(2, :), dat(3, :));
        drawnow expose;
        hold off
        pause(0.005);
    end
    close(figAnim)
end



end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function options = check_options(varargin)
if ~isempty(varargin)
    options = varargin{1};
    options.hasobstacle = 1;
else
    options.hasobstacle = 0;
    options.obstacle.position = [0 0];
    options.obstacle.radius = 0;
end

if ~isfield(options,'parentup') % convergence tolerance
    options.parentup = [];
end

if ~isfield(options,'animation') % convergence tolerance
    options.animation = 0;
end

if ~isfield(options,'matched_repros') % convergence tolerance
    options.matched_repros = [];
end
if ~isfield(options,'obstacle') % maximum number of iterations
    obstacle.position = [0 0];
    obstacle.radius = 0;
    options.obstacle=obstacle;
    options.hasobstacle = 0;
end
%options.matched_repros = [];



end
