function [YI VI fs GI]=CT_ReparametrizedByParameter(pos,v,dt,EXACT_SPD_TIME)
%%% reparametrization of pos according to the speed v where v is evaluated
%%% at the positions pos (in contrast to CT_Reparametrized where v was the
%%% ending speed profile with respect to time).
%   YI is the reparametrized position.
%   VI is the speed at the reparametrized curve YI (using interpolation). It
%   should be equivalent to the speed of YI.
%   The speed GI is the same as Vpos (parametrization of pos) but evaluated
%   at the points of YI.
%   all position vectors are MxN where M is the number of 
%   samples and N is the dimensionallity 

%   Further Remarks:
%   The speed at YI is not v (because v is the speed at the pos(i,:)).
%   If one reinterpolates YI near pos then the speed at those points will
%   be as the respective speed of v.
%   EXACT_SPD_TIME is a parameter which should be responsible for either
%   tunning the number of returned samples or the boundaries of the speed
%   profile, with values: ExactTime or ExactSpeed, ExactProfile
%   ExactProfile will uses the velocity v, hence changing the
%   number of samples in YI

%

% Written by Yaron Meirovitch 2010.

if ~exist('EXACT_SPD_TIME','var')
    EXACT_SPD_TIME = 'ExactTime';
end

ds_sigma = sqrt(sum(diff(pos).^2,2));
v_inter = (v(1:end-1)+v(2:end))/2;
T_sigma = [0; cumsum(ds_sigma./v_inter')];
%T_sigma = cumsum(1./v.*v_sigma'); old

%YI = INTERP1(T_sigma,pos,(1:length(T_sigma))*(T_sigma(end)/length(T_sigma)));
if exist('dt','var') && ~isempty(dt) && strcmp(EXACT_SPD_TIME,'ExactProfile')
    Tinput=length(v)*dt;
    t_step = (T_sigma(end)-T_sigma(1))/length(T_sigma)*Tinput/T_sigma(end);
else
    t_step = (T_sigma(end)-T_sigma(1))/length(T_sigma);
end


if strcmp(EXACT_SPD_TIME,'ExactTime')
    YI = interp1(T_sigma,pos,T_sigma(1):t_step:T_sigma(end)-t_step,'spline'); % -t_step is used in order to return the same number os sample (ExactTime)
    VI = interp1(T_sigma,v,T_sigma(1):t_step:T_sigma(end)-t_step,'spline');
    fs = 1/t_step;
    
    Vpos = sqrt(sum(gradient(pos',t_step)'.^2,2));
    GI = interp1(T_sigma, Vpos,T_sigma(1):t_step:T_sigma(end)-t_step,'spline');
elseif strcmp(EXACT_SPD_TIME,'ExactSpeed') ||  strcmp(EXACT_SPD_TIME,'ExactProfile') % ar the moment the difference is minor but still important due to implementation issues (that should be fixed later)
    YI = interp1(T_sigma,pos,T_sigma(1):t_step:T_sigma(end),'spline'); % the difference from ExactTime is the -t_step that is omitted here
    VI = interp1(T_sigma,v,T_sigma(1):t_step:T_sigma(end),'spline');
    fs = 1/t_step;
    Vpos = sqrt(sum(gradient(pos',t_step)'.^2,2));
    GI = interp1(T_sigma, Vpos,T_sigma(1):t_step:T_sigma(end),'spline');
end
%
%%vpos = sum(gradient(pos',dt).^2,2).^.5;
%%interp1(vpos,dt*(1:length(v)),GI);



