function [parameters] = CustomParameters()


%% Global parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% < should be set by the user > 
parameters.folder_models = 'EPFL_models'; % Please write the name of the folder that contains your models
                               % The program looks for the folder in
                               % ./LASA_Handwriting_motions/'your model folder'
parameters.folder_library = 'EPFL_lib'; % Please write the name of the folder that contains all the files
                             % for your algorithm. The program looks for the folder in
                               % ./'your algorithm folder'
parameters.folder_dataset = 'LASA_Handwriting_Dataset';

parameters.model = 'Angle';


%% Benchmark generalization

parameters.generalization.run = 1; %Do you wanna run this benchmark ?
parameters.generalization.plot = 1; %Do you wanna plot this benchmark ?
parameters.generalization.animation = 0; %Do you wanna animate this benchmark ?
parameters.generalization.plot_wait_time = 0.1; %waiting time in sec between plots. -1 = wait that you press ENTER
parameters.generalization.resultFile = 'generalization_results.mat'; %file to save the results of this benchmark.
parameters.generalization.start_time = 0; %start is fixed.
% parameters.pushes.amplitude = [40, 60, 80, 100, 120, 140, 160, 180, 200 ]; %the amplitude of the perturbation (multiplier of a normalized vector)
parameters.generalization.amplitude = [8, 10]; %the amplitude of the perturbation (multiplier of a normalized vector)
%parameters.pushes.amplitude = ['%rand%' '%numVal%' '2' '%dim%' '1' '%minVal%' '0' '%maxVal%' '100']; %numerical parameters can also be randomized by using this syntax
parameters.generalization.vector = [[-1 0]; [1 0]]'; %these vectors define the direction and will be normalized
%parameters.pushes.vector = ['%rand%' '%numVal%' '2' '%dim%' '2' '%minVal%' '-1' '%maxVal%' '1']; %numerical parameters can also be randomized by using this syntax

%% Benchmark pushes

parameters.pushes.run = 0; %Do you wanna run this benchmark ?
parameters.pushes.plot = 1; %Do you wanna plot this benchmark ?
parameters.pushes.animation = 0; %Do you wanna animate this benchmark ?
parameters.pushes.plot_wait_time = 0.1; %waiting time in sec between plots. -1 = wait that you press ENTER
parameters.pushes.resultFile = 'pushes_results.mat'; %file to save the results of this benchmark.
parameters.pushes.start_time = [0 0.5]; %start time of the perturbation.
% parameters.pushes.amplitude = [40, 60, 80, 100, 120, 140, 160, 180, 200 ]; %the amplitude of the perturbation (multiplier of a normalized vector)
parameters.pushes.amplitude = [8, 10]; %the amplitude of the perturbation (multiplier of a normalized vector)
%parameters.pushes.amplitude = ['%rand%' '%numVal%' '2' '%dim%' '1' '%minVal%' '0' '%maxVal%' '100']; %numerical parameters can also be randomized by using this syntax
parameters.pushes.vector = [[-1 0]; [1 0]]'; %these vectors define the direction and will be normalized
%parameters.pushes.vector = ['%rand%' '%numVal%' '2' '%dim%' '2' '%minVal%' '-1' '%maxVal%' '1']; %numerical parameters can also be randomized by using this syntax



%% Benchmark continuous pushes

parameters.cont_pushes.run = 0; %Do you wanna run this benchmark ?
parameters.cont_pushes.plot = 1; %Do you wanna plot this benchmark ?
parameters.cont_pushes.animation = 0; %Do you wanna animate this benchmark ?
parameters.cont_pushes.plot_wait_time = 0.1; %waiting time in sec between plots. -1 = wait that you press ENTER
parameters.cont_pushes.resultFile = 'cont_pushes_results.mat'; %file to save the results of this benchmark.
parameters.cont_pushes.start_time = [0.3 0.6]; %start time of the perturbation.
parameters.cont_pushes.duration = [0.2 0.3]; %duration of the perturbation.
parameters.cont_pushes.amplitude = [10 15]; %the amplitude of the perturbation (multiplier of a normalized vector)
%parameters.cont_pushes.amplitude = ['%rand%' '%numVal%' '10' '%dim%' '1' '%minVal%' '0' '%maxVal%' '100'];  %numerical parameters can also be randomized by using this syntax
parameters.cont_pushes.vector = [[-1 0]; [1 0]]'; %these vectors define the direction and will be normalized
%parameters.cont_pushes.vector = ['%rand%' '%numVal%' '10' '%dim%' '2' '%minVal%' '0' '%maxVal%' '1'];  %numerical parameters can also be randomized by using this syntax



%% Benchmark changing target
parameters.target.run = 0; %Do you wanna run this benchmark ?
parameters.target.plot = 1; %Do you wanna plot this benchmark ?
parameters.target.animation = 0; %Do you wanna animate this benchmark ?
parameters.target.plot_wait_time = 0.1; %waiting time in sec between plots.
parameters.target.resultFile = 'target_results.mat'; %file to save the results of this benchmark.
parameters.target.start_time = [0 0.5]; %start time of the perturbation.
parameters.target.duration = [0.2 0.4]; %duration of the perturbation.
parameters.target.amplitude = [10 15]; %the amplitude of the perturbation (multiplier of a normalized vector)
%parameters.target.amplitude = [ 0, 0]; %the amplitude of the perturbation (multiplier of a normalized vector)
parameters.target.vector = [[1 1]; [1 0]]'; %these vectors define the direction and will be normalized
%parameters.target.vector = [[0 0] [0 0]]'; %these vectors define the direction and will be normalized




%% Benchmark obstacle
parameters.obstacle.run = 0; %Do you wanna run this benchmark ?
parameters.obstacle.plot = 1; %Do you wanna plot this benchmark ?
parameters.obstacle.animation = 0; %Do you wanna animate this benchmark ?
parameters.obstacle.plot_wait_time = 0.1; %waiting time in sec between plots.
parameters.obstacle.resultFile = 'obstacle_results.mat'; %file to save the results of this benchmark.
parameters.obstacle.appear_time = [0.0 0.3]; %time at which the obstacles appears.
parameters.obstacle.forsee_time = [0.2 0.3]; %time before the trajectory of the demo hits the obstacle 
                                           %(basically defines the position of the obstacle in the trajectory frame).
%parameters.obstacle.position = [[-20 20]; [-20 -30]; [-30 -20]; [-40 -20]]'; %these vectors absolute position of the obstacles
parameters.obstacle.radius = [5 8]; %radius in mm

% < BENCHMARK PARAMETERS > 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



end

