function [statistics]=PowerLawCompliance(trj,dt,TimeWindows)
%%% demo, repro are Nx2 trajectories 
%%% dt is 1/samplingrate
fs=1/dt; % the sampling frequency 
R2iw=[];

resampTh=1000; % #samples, this is used to shorten long trajectories and save computation time

if size(trj,1)<300
    % this is actually a warning
    disp('trajectory is short. Interpreting the scores should be done with caution.');
    Nf=ceil(size(trj,1)/3-1);
    if Nf<1
        statistics=nan(size(TimeWindows,2),2);
        return
    end
else
    Nf=95;
end
Wf=fir1(Nf,4/(fs/2)); %% we may need to make the window size (now 95) be a function of dt as well
trj=filtfilt(Wf,[1],trj(all(~isnan(trj')),:));

if size(trj,1)>resampTh
    dt=dt*size(trj,1)/resampTh;
    fs=1/dt;
    trj=interp1(1:size(trj,1),trj,linspace(1,size(trj,1),resampTh),'cubic');
    
end
    
remove_boundaries=0.5; % percentage
speed=sum(gradient(trj',dt)'.^2,2).^.5;
speed=speed/median(speed);
kappa=curvetorsion(trj);

klow=prctile(kappa,30); % remove from regression low kappa values
Is=find(speed>remove_boundaries,1,'first');
Ie=find(speed>remove_boundaries,1,'last');
Ik=find(kappa<klow);
I=setdiff(Is:Ie,Ik);
%fitpowerlawsegment(trj,1,1000,0,0,fs);

%figure; plot(log(kappa(I)),log(speed(I)),'.'); axis equal
spd_anal=speed; spd_anal(setdiff(1:length(trj),I))=nan;
kappa_anal=kappa; kappa_anal(setdiff(1:length(trj),I))=nan;
%figure; plot(speed(I)); hold all; plot(15*kappa(I).^(1),'.'); ylim([0 8])
%figure; plot(spd_anal); hold all; plot(15*kappa_anal.^(1),'.'); ylim([0 8])

W=round(TimeWindows*fs);
for iw=1:length(W)
    w0=W(iw);
    sw=1:w0;
    slide_index=0;
    R2=[];
    pval=[];
    while max(sw)<=length(I)
        slide_index=slide_index+1;
        J=I(sw);
        [p, s, mu]=polyfit(log(kappa(J)),log(speed(J)),1);
        [logspeedfit, delta] = polyval(p,log(kappa(J)),s,mu); % having the unused delta may improve running time
        %[rho, pval(slide_index,:,:)]=corr([log(kappa(J)),log(speed(J))]);
        %figure; plot(logspeedfit,'.'); hold all; plot(log(speed(J)),'.')
        R2(slide_index)=1-sum((logspeedfit-log(speed(J))).^2)/sum((mean(log(speed(J)))-log(speed(J))).^2);
        sw=sw+round(1.5*fs/10);
    end
    %figure; plot(log10(squeeze(pval(:,1,2))),R2,'.')
    %if isnan(mean(R2)) || w0/fs>1.5
    %    1;
    %end
    R2iw(iw,:)=[mean(R2) std(R2)/sqrt(slide_index)];
end

isNanR2=any(isnan(R2iw),2);
if sum(isNanR2) >= length(isNanR2)-1
    statistics=nan(length(W),2);
else
    statistics=interp1(W(~isNanR2)'/fs,R2iw(~isNanR2,:),TimeWindows','linear','extrap'); % correcting to common values. no need for cubic spline
end
%figure;
%highR2=find(R2iw(:,1)>0.4);
%errorbar(W(highR2)/fs,R2iw(highR2,1),-R2iw(highR2,2),R2iw(highR2,2),'.');


