% clear all
dataSetName = {'LASA_Handwriting_Dataset'};
participants = {'EPFL_models'};
benchmarks = {'generalization_results'}; %'pushes_results','cont_pushes_results','target_results'
colorStr = {'blue','green','red','black'};

%Threshold:
meanAccuracy = 1;
maxR2 = 0.95;
maxR2speed = 0.8;
maxPowerLaw = 0.0;
nFinalTimeErrMargin = 0.1;

%%

thresholdVector = [0.0 0.0 meanAccuracy 0.0 0.0 0.0 0.0 maxPowerLaw maxR2 maxR2speed nFinalTimeErrMargin];

figFinal = figure('name','Final Result','position',[200 100 1200 650]);
ystr = {' ', '  Processing\newline Time (msec)', 'Module Size\newline     (bytes)';
        'Target Position\newline   Error (mm)','Target Velocity\newline  Error (mm/s)','Mean Jerk (m/s^3)';
        'Path Error (mm)','Trajectory Velocity\newline    Error (mm/s)',' Power Law\newline Score (%R^2)';
        'R2','R2 speed','Normalized Final\newline     Time Error'};
    
pos0 = [0.06    0.80    0.26    0.165];
axisFinalResult = zeros(size(ystr));
for i=1:size(axisFinalResult,1)
    for j=1:size(axisFinalResult,2)
        c = (i-1)*size(axisFinalResult,2) + j;
        axisFinalResult(c) = subplot(size(axisFinalResult,1),size(axisFinalResult,2),c, 'Parent', figFinal);
        %         xlabel(ss(c),'iteration','fontsize',9);
        ylabel(axisFinalResult(c),ystr{i,j},'fontsize',11);
        hold(axisFinalResult(c), 'on'); box(axisFinalResult(c), 'on');grid(axisFinalResult(c), 'on');
        set(axisFinalResult(c),'Position',pos0 + [(j-1)*0.33 -(i-1)*0.24 0 0])
    end
end
delete(axisFinalResult(1))
axisFinalResult(1) = [];
annotation('textbox',[0.06 0.85 0.26 0.06],'string','Final Results',...
        'Fontsize',20,'HorizontalAlignment','center','LineStyle','none');
%%
for i_dataSet = 1:length(dataSetName)
    for i_participant = 1:length(participants)
        curFolder = ['results' filesep dataSetName{i_dataSet} filesep participants{i_participant}];
        if exist(curFolder,'dir')
            tmpModels = dir([curFolder filesep '*']);
            modelCell = cell(length(tmpModels)-2,1);
            for i = 3:length(tmpModels)
                modelCell{i-2} =tmpModels(i).name;
            end
        else
            tmpModels = [];
            modelCell = [];
        end
        
        score4Plot_mean = [];
        score4Plot_var = [];
        for i_model=1:length(modelCell)
            %going through different benchmarks
            for i_benchmarks = 1:length(benchmarks)
                curFilename = [curFolder filesep modelCell{i_model} filesep benchmarks{i_benchmarks}];
                if length(dir([curFilename '*.*'])) == 1
                    load(curFilename,'results') %loading the results for each benchmark of each model
                    clear targetErrorPos targetErrorVel trajErrorPos trajErrorVel R2 R2_speed meanJerk PL_R2 normalizedFinalTimeError
                    for j=1:length(results);
                        for i=1:length(results(j).demos)
                            computationTime(j,i) = mean(results(j).demos(i).computationTime)*1000; %converting to msec
                            targetErrorPos(j,i) = norm(results(j).demos(i).target_error.position);
                            targetErrorVel(j,i) = norm(results(j).demos(i).target_error.velocity);
                            trajErrorPos(j,i) = norm(results(j).demos(i).trajectory_error.position);
                            trajErrorVel(j,i) = norm(results(j).demos(i).trajectory_error.velocity);
                            R2(j,i) = results(j).demos(i).R2;
                            R2_speed(j,i) = results(j).demos(i).R2_speed;
                            meanJerk(j,i) = norm(results(j).demos(i).mean_jerk);
                            PL_R2(j,i) = results(j).demos(i).PL_R2;
                            normalizedFinalTimeError(j,i) = abs(results(j).demos(i).normalizedFinalTime - 1.0);
                        end
                    end
                    modelSize = results(1).modelSize;

                    criteriaStr = {'computationTime','modelSize','targetErrorPos','targetErrorVel','meanJerk',...
                            'trajErrorPos','trajErrorVel','PL_R2','R2','R2_speed','normalizedFinalTimeError'};
                    for c=1:length(criteriaStr)
                        eval([' currentMetic = ' criteriaStr{c} '(:);']);
                        score4Plot_mean{c}(i_model,i_benchmarks) = mean(currentMetic);
                        score4Plot_var{c}(i_model,i_benchmarks)  = sqrt(var(currentMetic));
                        eval(['performance.' benchmarks{i_benchmarks} '.' criteriaStr{c} '.' modelCell{i_model} '.mean = score4Plot_mean{c}(i_model,i_benchmarks);']);
                        eval(['performance.' benchmarks{i_benchmarks} '.' criteriaStr{c} '.' modelCell{i_model} '.variance = score4Plot_var{c}(i_model,i_benchmarks);']);
                    end
                end
            end
        end
        %% Plotting detailed results for each participant for all models
        tLabel = ['Benchmark Result for ' participants{i_participant} ' on ' dataSetName{i_dataSet}];
        figDetailed(i_participant) = figure('name',tLabel,'position',[200 100 1200 650]);
%         pos0 = [0.06    0.795    0.4    0.13];
        axisDetailedResult = zeros(size(ystr));
        for i=1:size(axisDetailedResult,1)
            for j=1:size(axisDetailedResult,2)
                c = (i-1)*size(axisDetailedResult,2) + j;
                axisDetailedResult(c) = subplot(size(axisDetailedResult,1),size(axisDetailedResult,2),c, 'Parent', figDetailed(i_participant));
                %         xlabel(ss(c),'iteration','fontsize',9);
                ylabel(axisDetailedResult(c),ystr{i,j},'fontsize',11);
                hold(axisDetailedResult(c), 'on'); box(axisDetailedResult(c), 'on');grid(axisDetailedResult(c), 'on');
                set(axisDetailedResult(c),'Position',pos0 + [(j-1)*0.33 -(i-1)*0.24 0 0])
            end
        end
        delete(axisDetailedResult(1))
        axisDetailedResult(1) = [];
%         title(ss(1),regexprep(tLabel,'_',' '));
%%
        for c=1:length(criteriaStr)
            [nbModel nbBenchmark] = size(score4Plot_mean{c});
            barWidth = 1/(4+nbBenchmark+(nbBenchmark-1)/4);
            for i=1:nbBenchmark
                barOffset = -0.5+2.5*barWidth+1.25*(i-1)*barWidth;
                x = [1:nbModel]+barOffset;
                hbd(i) = bar(axisDetailedResult(c),x,score4Plot_mean{c}(:,i),barWidth);
                set(hbd(i),'facecolor',colorStr{i});
                errorbar(axisDetailedResult(c),x,score4Plot_mean{c}(:,i)',score4Plot_var{c}(:,i)','xk')
            end
            set(axisDetailedResult(c),'Xtick',1:length(modelCell),'XTickLabel',modelCell);
            axis(axisDetailedResult(c),'tight');
            ax=get(axisDetailedResult(c));
            axis(axisDetailedResult(c),[0.5 nbModel+0.5 ...
                ax.YLim(1)-(ax.YLim(2)-ax.YLim(1))/10 ax.YLim(2)+(ax.YLim(2)-ax.YLim(1))/10]);
        end

        l = legend(axisDetailedResult(1),hbd,regexprep(regexprep(benchmarks,'_results',''),'_',' '),'fontsize',11);
        pos_l = get(l,'position');
        set(l,'position',[(pos0(1)+0.33-pos_l(3))/2 0.8 pos_l(3:4)]);
        
        %% Plotting the final result for the current participant
        for c=1:length(criteriaStr)
            finalScore(c,i_participant) = mean(mean(score4Plot_mean{c},1));
            hbf = bar(axisFinalResult(c),i_participant,finalScore(c,i_participant),barWidth);
            set(hbf,'facecolor',colorStr{i_participant});
            set(axisFinalResult(c),'Xtick',1:length(participants),'XTickLabel',participants);

            axis(axisFinalResult(c),'tight');
            ax=get(axisFinalResult(c));
            axis(axisFinalResult(c),[0.5 length(participants)+0.5 ...
                ax.YLim(1)-(ax.YLim(2)-ax.YLim(1))/10 ax.YLim(2)+(ax.YLim(2)-ax.YLim(1))/10]);
        end
    end
    %% finding the best participant
    figure(figFinal)
    for c=1:length(criteriaStr)
        if any(c == [1 2 3 4 5 6 7 11])
            [value standing] = sort(finalScore(c,:),'ascend');
            bSort = 1; 
        else
            [value standing] = sort(finalScore(c,:),'descend');
            bSort = -1;
        end
        for r = 1 : size(standing,2)
            if bSort*value(r) <= bSort*thresholdVector(c)
                currentRank = 1;
            elseif r==1 || value(r) ~= value(r-1) %we need to have this procedure to account for the case where two groups have exactly the same score
                currentRank = r;
            end
            axes(axisFinalResult(c))
            text(standing(r),finalScore(c,standing(r))/2,['$\textbf{\underline{' num2str(currentRank) '}}$'],...
                'fontsize',12,'interpreter','latex','HorizontalAlignment','center','VerticalAlignment','middle')
        end
    end
end