function [results log] = generalEvaluation(demo, repro,xT, domain)
% description goes here
% domain is an optional variable that contains the unperturbed domain

% move deomain to the demonstrations coordinates
if ~exist('domain','var')
    % size of demo is the common size for comparison after temporal normalization
    domain= true(1,size(demo,1)); % true is logical(1)
elseif ~isempty(domain)
        domain=logical(interp1(1:length(domain),double(domain),linspace(1,length(domain),size(demo,1)),'nearest'));       
end

%create tmp variables
pos_r = repro;
pos_d = demo;
vel_d = gradient(pos_d')'; % this is not used but can be used
vel_r = gradient(pos_r')';

%normalize in time
vel_ = ones(1,size(pos_r,1));
[YI VI fs GI]=CT_ReparametrizedByParameter(pos_r,vel_);
VI=gradient(YI')';

[sd I]= unique(pos_d,'rows','first');
pos2_=pos_d(sort(I),:);
vel2_ = ones(1,size(pos2_,1));%normalize in time
[YI2 VI2 fs2 GI2]=CT_ReparametrizedByParameter(pos2_,vel2_);
VI2=gradient(YI2')';

% does not change kinematics.
[demo_, repro_] = ResampleData(pos_d, pos_r);

[demoS, reproS] = ResampleData(YI2, YI);
if size(demo_,1)~=size(repro_,1)
keyboard
end
%% Finding best match of demonstration and reproduction
% with kinematics
[tmpVaris, transf_Repro_kin, tmpVaris] = procrustes(demo_, repro_,'Reflection',false,'scaling',true);
% without kinematics
[tmpVaris, transf_Repro, tmpVaris] = procrustes(demoS, reproS,'Reflection',false,'scaling',true);


fitness = goodnessOfFitStatisticR2(demo_',transf_Repro_kin');% additional fitness value


transf_Repro=[transf_Repro gradient(transf_Repro')'];
log.matched_r=transf_Repro;

%% error between demonstrations and reproductions for both position and velocity
err = abs(reproS - demoS); %error between the demonstration and the achieved trajectory over time
log.err = err;

log.pos_r = repro_;
log.pos_d = demo_;


RMSE_over_path = sqrt(mean(diag(err*err'))); %rooted mean squared error for each demo

repro_vel = gradient(repro_')';
repro_speed = sqrt(diag(repro_vel*repro_vel'));

demo_vel =gradient(demo_')';
demo_speed = sqrt(diag(demo_vel*demo_vel'));

fitness_speed = goodnessOfFitStatisticR2(demo_speed(domain)',repro_speed(domain)');% additional fitness value

err_vel = abs(repro_vel - demo_vel); %error between the demonstration and the achieved trajectory over time

RMSE_over_trajectory_vel = sqrt(mean(diag(err_vel(domain,:)*err_vel(domain,:)'))); %rooted mean squared error for each demo

traj_position_error =RMSE_over_path;
traj_velocity_error = RMSE_over_trajectory_vel;

%% save resultsfit = goodnessOfFitStatisticR2(demo,repro)
results.trajectory_error.position = traj_position_error;
results.trajectory_error.velocity = traj_velocity_error;

results.vssq = vssqVelocityMeasure([demo_ gradient(demo_')']',[repro_ gradient(repro_')']');% additional fitness value
results.R2 = fitness;
results.R2_speed = fitness_speed;

% Fields are filled in the corresponding benchmark files
results.max_jerk = -1;
results.mean_jerk = -1;
results.computationTime = nan;
results.normalizedFinalTime = nan;
results.PL_R2 = nan;
results.domain = domain;
results.target_error.position = nan;
results.target_error.velocity = nan;

end